<?php
/*
Plugin Name: GeoURL
Plugin URI: http://sites.google.com/site/wpgeourl/ 
Description: GeoURL plugin allows you to configure your real-world location in order to find other websites nearby to you.
Version: 0.1
Author: Aimee Daniells
Author URI: http://aimee.mychores.co.uk
*/

define('GEOURL_LONGITUDE_OPTION', 'geourl_longitude');
define('GEOURL_LATITUDE_OPTION', 'geourl_latitude');

function geourl_reset_settings() {
	delete_option(GEOURL_LATITUDE_OPTION);
	delete_option(GEOURL_LONGITUDE_OPTION);
}

function geourl_has_settings() {
	$latitude = get_option(GEOURL_LATITUDE_OPTION);
	$longitude = get_option(GEOURL_LONGITUDE_OPTION);
	return !empty($latitude) && !empty($longitude);
}

add_action('init', 'geourl_init');

function geourl_init() {
	add_action('admin_menu', 'geourl_admin_menu');
	add_action('wp_head', 'geourl_head');
}

function geourl_admin_menu() {
	add_options_page(__('GeoURL Settings'), __('GeoURL'), 8, __FILE__, 'geourl_settings');
}

function geourl_settings() {
	if (isset($_POST['submit'])) {
		if (!current_user_can('manage_options')) {
			die(__('Unauthorized access!'));
		}
		if (isset($_POST['geourl_latitude'])) {
			$latitude = $_POST['geourl_latitude'];
			if (empty($latitude)) {
				delete_option(GEOURL_LATITUDE_OPTION);
			} else {
				update_option(GEOURL_LATITUDE_OPTION, $latitude);
			}
		}
		if (isset($_POST['geourl_longitude'])) {
			$longitude = $_POST['geourl_longitude'];
			if (empty($longitude)) {
				delete_option(GEOURL_LONGITUDE_OPTION);
			} else {
				update_option(GEOURL_LONGITUDE_OPTION, $longitude);
			}
		}
?>
<div id="geourl_warning" class="updated fade">
	<p><strong><?php _e('GeoURL:'); ?></strong> Settings saved! <a href="http://geourl.org/ping?p=<?php urlencode(bloginfo('url')); ?>" target="_blank">Click here</a> to send a ping to the GeoURL server</p>
</div>
<?php
	}

	$latitude = get_option(GEOURL_LATITUDE_OPTION);
	$longitude = get_option(GEOURL_LONGITUDE_OPTION);

?>
<div class="wrap">
	<h2><?php _e('GeoURL Settings'); ?></h2>
	<div id="poststuff" class="metabox-holder">
		<form name="form0" method="post" action="">
			<div class="postbox open">
				<h3 class="hndle"><?php _e('GeoURL Settings'); ?></h3>
				<div class="inside">
					<table class="form-table">
						<tr>
							<th><label for="geourl_latitude"><?php _e('Latitude:'); ?></label></th>
							<td><input type="text" id="geourl_latitude" name="geourl_latitude" value="<?php echo $latitude; ?>" /></td>
							<td>(degrees North, e.g. <strong>51.50038</strong>)</td>
						</tr>
						<tr>
							<th><label for="geourl_longitude"><?php _e('Longitude:'); ?></label></th>
							<td><input type="text" id="geourl_longitude" name="geourl_longitude" value="<?php echo $longitude; ?>" /></td>
							<td>(degrees East, e.g. <strong>-0.15482</strong>)</td>
						</tr>
					</table>
				</div>
			</div>
			<p class="submit">
				<input type="submit" name="submit" value="<?php _e('Save Settings'); ?>" class="button-primary" />
			</p>
		</form>	
					
		<br />
		
		<h3>How to find your latitude and longitude</h3>
		<img style="float: right; margin: 1em; border: 1px solid #dfdfdf;" src="../wp-content/plugins/geourl/multimap.png" width="261" height="160" alt="Finding latitude and longitude on Multimap" />
		<p>Look up your location on <a href="http://www.multimap.com" target="_blank">Multimap</a></p>
		<p>Look under "Map information" for the numbers in the brackets</p>
		<p>Use an approximate location if you are concerned about privacy.</p>
		<div class="clear" />
		
	</div>
</div>
<?php
}

if (!geourl_has_settings() && !isset($_POST['submit'])) {
	add_action('admin_notices', 'geourl_admin_notices');
}

function geourl_admin_notices() {
?>
<div id="geourl_warning" class="updated fade">
	<p><strong><?php _e('GeoURL:'); ?></strong> You need to <a href="options-general.php?page=geourl/geourl.php">enter your location in the settings page</a>!</p>
</div>
<?php
}

function geourl_head() {
	if (geourl_has_settings()) {
		$latitude = get_option(GEOURL_LATITUDE_OPTION);
		$longitude = get_option(GEOURL_LONGITUDE_OPTION);
?>

<!-- GeoURL Plugin - Start -->
<meta name="ICBM" content="<?php echo $latitude; ?>, <?php echo $longitude; ?>" />
<meta name="DC.Title" content="<?php bloginfo('name'); ?>" />
<!-- GeoURL Plugin - End -->

<?php
	}
}

?>
